﻿/* Copyright (C) Click & Push Accessibility, Inc - All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written and maintained by the Click & Push Development team 
 * <dev@clicknpush.ca>, January 2022
 */

import { useNavigationState } from "@react-navigation/native";
import { observer } from "mobx-react";
import React, { useEffect, useState } from "react";
import { Image, ScrollView, StyleSheet, Text, TextInput, View } from "react-native";
import { store } from "../../../../main-store";
import { LandmarkTypeIconMap, lmTypes, lmTypesIndoor } from "../../../../utils/GlobalUtils";
import { LandmarkTypePicker } from "../../../LandmarkTypePicker";
import { Separator } from "../../../Separator";
import { CommentsContainer } from "./comments-container";
import { LandmarkPhotos } from "./landmark-photos";
import { useSelectedLandmarkContext } from "./selected-landmark-panel.context";

/**
     * Sub-component that renders picker for landmark types
     * @param 
     */
 const LandmarkTypePickerContainer: React.FC = observer(() => {
    const navigationState = useNavigationState(state => state)
    const [currentLmTypes, setLmTypes] = useState<LandmarkTypeIconMap>(lmTypes)
    const {landmarkQuery} = useSelectedLandmarkContext();

    useEffect(() => {
        const currentRouteIndex = navigationState?.routes[0]?.state?.index
        const currentRouteName = navigationState?.routes[0]?.state?.routeNames[currentRouteIndex]

        if (currentRouteName == "Indoor") {
            setLmTypes(lmTypesIndoor)
        }
    }, [navigationState])

    

    return (
    <View style={{flexDirection: 'row', marginBottom: 20, justifyContent: "space-between"}}>
        {store.selectedLm.pendingLandmarkData?.landmark_type ? 
        <>
            <LandmarkTypePicker 
                placeholder={{}}
                value={store.selectedLm.pendingLandmarkData?.landmark_type} 
                onValueChange={(value) => {
                    store.selectedLm.setPendingLandmarkData({...store.selectedLm.pendingLandmarkData, landmark_type: value, title: lmTypes[value].label})
                }}  
                items={Object.keys(lmTypes)?.filter(icon => parseInt(icon) != landmarkQuery.data?.landmark?.landmark_type).map(icon => {
                    return (
                        {label: lmTypes[parseInt(icon)].label.toUpperCase(), value: icon, key: icon}
                    )})}/>
            {store.selectedLm.pendingLandmarkData ? <Image style={{marginLeft: 20}} source={lmTypes[store.selectedLm.pendingLandmarkData?.landmark_type].image}/> : null}
        </>
        : null}
    </View>
    )
})

/**
     * Sub-component that renders the view to be displayed when editing is disabled
     * @param 
     */
const EditingDisabledUpperView: React.FC = () => {
    const {landmarkQuery} = useSelectedLandmarkContext();

    return (
        <View style={{flexDirection: 'row', justifyContent: 'space-between'}}>
            <View style={{flex: 8, flexDirection: 'column', marginBottom: 20}}>
                <Text style={{color: 'white', marginBottom: 10, fontSize: 15}}>{lmTypes[landmarkQuery.data?.landmark?.landmark_type]?.label.toUpperCase()}</Text>
                <ScrollView nestedScrollEnabled={true}>
                    <Text style={{color: 'white', fontSize: 13}}>{landmarkQuery.data?.landmark?.description}</Text>
                </ScrollView>
            </View>
            {landmarkQuery.data?.landmark?.landmark_type ? <Image source={lmTypes[landmarkQuery.data?.landmark?.landmark_type]?.image} /> : null}
        </View>
    )
}

/**
 * Component that renders the body of the Landmark details panel
*/
export const DetailsBody: React.FC = observer((props) => {
    const {landmarkQuery, mainScrollRef} = useSelectedLandmarkContext();
    useEffect(() => {
        console.log(landmarkQuery.data?.landmark)
    }, [landmarkQuery.data?.landmark])

    useEffect(() => {
        if (store.selectedLm.editing) {
            console.log("[LandmarkDetails]: Editing is enabled")
            store.selectedLm.setPendingLandmarkData(landmarkQuery.data?.landmark);
        }
        else {
            store.selectedLm.setPendingLandmarkData(undefined);
        }
    }, [store.selectedLm.editing])

    return (
        <ScrollView ref={mainScrollRef} nestedScrollEnabled={true} contentContainerStyle={{justifyContent: 'space-between'}} style={{flex: 1, marginHorizontal: 20}}>
            {store.selectedLm.editing ?
            <>
                <LandmarkTypePickerContainer />
                <Separator style={{marginBottom: 20, opacity: .5}} color="lightgray" />
                <Text style={{color: 'white', marginBottom: 10}}>Description</Text>
                <ScrollView nestedScrollEnabled={true} style={{backgroundColor: 'white', marginBottom: 20}}>
                    <TextInput 
                        multiline={true} 
                        style={[styles.input, {fontSize: 13, marginBottom: 10}]}
                        onChangeText={text => store.selectedLm.setPendingLandmarkData({...store.selectedLm.pendingLandmarkData, description: text})} 
                        value={store.selectedLm.pendingLandmarkData?.description}/>
                </ScrollView>
            </>: <EditingDisabledUpperView />}
            {!store.selectedLm.editing ?
            <CommentsContainer/> : null}
            {!store.selectedLm.editing && !store.global.keyboardOpen ?
            <LandmarkPhotos />
             : null}
            
        </ScrollView>
    )
})

const styles = StyleSheet.create({
    input: {
        padding: 5,
        color: 'black'
    },
    commentContainer: {
        flex: 5,
        marginBottom: 40,
    },
})
