import { makeAutoObservable } from "mobx";
import { Landmark } from "../types";

export class SelectedLandmarkStore {
    loadingLandmark = false;
    selectedLandmark?: Landmark;
    pendingLandmarkData?: Landmark;
    panelVisible: boolean = false;
    editing: boolean = false;
    selectedImageIndex: number = -1;
    processingPhoto = false;

    constructor() {
        makeAutoObservable(this);
    }

    async selectLandmark(id: string) {
        this.panelVisible = true;
        this.loadingLandmark = true;
        const response = await sendApiRequestAsync({
            axiosConfig: {
                method: 'GET',
                url: `/api/landmark/${id}/`,
            },
            authorized: !!userId,
            errorMessage: 'Something went wrong when retrieving the landmark',
            loggingCategory: 'LANDMARKS'
        });   
        return response?.data 
    } 

    close() {
        this.selectedLandmarkId = "";
        this.pendingLandmarkData = undefined;
        this.panelVisible = false;
    }

    setEditing(editing: boolean) {
        this.editing = editing;
    }

    selectImage(index: number) {
        this.selectedImageIndex = index;
    }

    setPendingLandmarkData(landmark: Landmark) {
        this.pendingLandmarkData = landmark;
    }

    setProcessingPhoto(processing: boolean) {
        this.processingPhoto = processing;
    }

    async getLandmark(id: string) => {
        
    }
}